==> igniteui-angular-charts-16.1.2-beta.0.tgz: package/esm5/lib/NegativeVolumeIndexIndicator.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { StrategyBasedIndicator } from "./StrategyBasedIndicator";
import { NegativeVolumeIndexIndicatorStrategy } from "./NegativeVolumeIndexIndicatorStrategy";
import { markType } from "igniteui-angular-core";
/**
 * @hidden
 */
var NegativeVolumeIndexIndicator = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(NegativeVolumeIndexIndicator, _super);
    function NegativeVolumeIndexIndicator() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    NegativeVolumeIndexIndicator.prototype.get_up = function () {
        return new NegativeVolumeIndexIndicatorStrategy();
    };
    Object.defineProperty(NegativeVolumeIndexIndicator.prototype, "up", {
        get: function () {
            return this.get_up();
        },
        enumerable: false,
        configurable: true
    });
    NegativeVolumeIndexIndicator.prototype.get_u2 = function () {
        return NegativeVolumeIndexIndicator.$;
    };
    Object.defineProperty(NegativeVolumeIndexIndicator.prototype, "u2", {
        get: function () {
            return this.get_u2();
        },
        enumerable: false,
        configurable: true
    });
    NegativeVolumeIndexIndicator.$t = markType(NegativeVolumeIndexIndicator, 'NegativeVolumeIndexIndicator', StrategyBasedIndicator.$);
    return NegativeVolumeIndexIndicator;
}(StrategyBasedIndicator));
export { NegativeVolumeIndexIndicator };

==> igniteui-angular-charts-17.2.0-beta.0.tgz: package/esm5/lib/NegativeVolumeIndexIndicator.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { StrategyBasedIndicator } from "./StrategyBasedIndicator";
import { NegativeVolumeIndexIndicatorStrategy } from "./NegativeVolumeIndexIndicatorStrategy";
import { markType } from "igniteui-angular-core";
/**
 * @hidden
 */
var NegativeVolumeIndexIndicator = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(NegativeVolumeIndexIndicator, _super);
    function NegativeVolumeIndexIndicator() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    NegativeVolumeIndexIndicator.prototype.get_yy = function () {
        return new NegativeVolumeIndexIndicatorStrategy();
    };
    Object.defineProperty(NegativeVolumeIndexIndicator.prototype, "yy", {
        get: function () {
            return this.get_yy();
        },
        enumerable: false,
        configurable: true
    });
    NegativeVolumeIndexIndicator.prototype.get_zb = function () {
        return NegativeVolumeIndexIndicator.$;
    };
    Object.defineProperty(NegativeVolumeIndexIndicator.prototype, "zb", {
        get: function () {
            return this.get_zb();
        },
        enumerable: false,
        configurable: true
    });
    NegativeVolumeIndexIndicator.$t = markType(NegativeVolumeIndexIndicator, 'NegativeVolumeIndexIndicator', StrategyBasedIndicator.$);
    return NegativeVolumeIndexIndicator;
}(StrategyBasedIndicator));
export { NegativeVolumeIndexIndicator };
